#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.1
visibility:           public
id:                   posix-paths-0.3.0.1-E5vdrtqBhtCC5viqHycSJ8
key:                  posix-paths-0.3.0.1-E5vdrtqBhtCC5viqHycSJ8
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  344bcaa6257030f2878e2581a365672a
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.1-E5vdrtqBhtCC5viqHycSJ8
depends:
    base-4.18.2.1 bytestring-0.11.5.3 unix-2.8.4.0
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

